@@ -36,7 +36,6 @@ def main():
     list(d)
 
     ## Munge playerInfo to conform to ColonelPanic's Needs
-    players=[]
     for clientNum, player in d.gamestate.players.items():
         for key, value in player.items():
             new_name=playerinfo_override.get(key, None)
@@ -48,7 +47,6 @@ def main():
             player['team']=TEAM_STRING_MAP[player['team']]
         if int(d.gamestate.config['serverinfo']['g_gametype']) >= GT_TEAM and 't' in player:
             player['team']=TEAM_STRING_MAP[player['t']]
-        players.append(player)
 
     # Calculate demo duration
     ## FIXME - I think serverTime is in msec, but it is a guess based
@@ -75,8 +73,8 @@ def main():
               'mapname': d.gamestate.config['serverinfo']['mapname'],
               'duration': duration}
 
-    output['scores'] = d.scores[-1] if d.scores else {}
-
+    #output['scores'] = d.scores[-1] if d.scores else {}
+    output['scores'] = {}
     if int(d.gamestate.config['serverinfo']['g_gametype']) >= GT_TEAM:
         output['scores']['TEAM_RED'] = {}
         output['scores']['TEAM_BLUE'] = {}
